Learn R Programming

BayesGESM (version 1.4)

bsp.graph.gesm: Tool for plotting the nonlinear effects that are approximated by using B-splines for generalized elliptical semi-parametric models

Description

bsp.graph displays the graphs of the nonparametric effects from an object of the class gesm().

Usage

bsp.graph.gesm(object, which, var, xlab, ylab, main)

Arguments

object
An object of the class gesm() or fmem().
which
An integer value, where 1 indicates location submodel, and 2 indicates dispersion submodel.
var
The name of the variable that is approximate using B-splines.
xlab
(optional) A title for the x axis
ylab
(optional) A title for the y axis
main
(optional) An overall title for the graph.