Learn R Programming

BayesGESM (version 1.4)

mcmc.gesm: MCMC algorithm for Generalized Elliptical Semi-parametric Models

Description

This function implements the MCMC algorithm derived in order to draw samples of the posterior distribution of the interest parameters in generalized elliptical semi-parametric models, which combines Gibbs sampler and Metropolis-Hastings algorithm.

Usage

mcmc.gesm(params)

Arguments

params
An object type list, which provides the setup (i.e., values of hyperparameters, initial values, model matrices, basis functions for the B-splines, burn-in and posterior sample size) of the model requested by the user.