mcmc.fmem: MCMC algorithm for Flexible Measurement Error Models
Description
This function implements the MCMC algorithm derived in order to draw samples of
the posterior distribution of the interest parameters in flexible measurement error models
under the presence of homocedastic and heterocedastic random errors.
Usage
mcmc.fmem(params)
Arguments
params
An object type list, which provides the setup (i.e., values of hyperparameters, initial values, model matrices, basis functions for
the B-splines, burn-in and posterior sample size) of the model requested by the user.